==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/UpgradeDependencies.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Upgrade node project dependencies.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.891Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.UpgradeDependencies")
public class UpgradeDependencies extends io.github.cdklabs.projen.Component {

    protected UpgradeDependencies(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected UpgradeDependencies(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public UpgradeDependencies(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public UpgradeDependencies(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Called before synthesis.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void preSynthesize() {
        software.amazon.jsii.Kernel.call(this, "preSynthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Whether or not projen is also upgraded in this workflow,.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getIgnoresProjen() {
        return software.amazon.jsii.Kernel.get(this, "ignoresProjen", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     * (experimental) The workflows that execute the upgrades.
     * <p>
     * One workflow per branch.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.github.GithubWorkflow> getWorkflows() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class))));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.UpgradeDependencies}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.UpgradeDependencies> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * (experimental) List of package names to exclude during the upgrade.
         * <p>
         * Default: - Nothing is excluded.
         * <p>
         * @return {@code this}
         * @param exclude List of package names to exclude during the upgrade. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(final java.util.List<java.lang.String> exclude) {
            this.options().exclude(exclude);
            return this;
        }

        /**
         * (experimental) Whether or not to ignore projen upgrades.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param ignoreProjen Whether or not to ignore projen upgrades. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ignoreProjen(final java.lang.Boolean ignoreProjen) {
            this.options().ignoreProjen(ignoreProjen);
            return this;
        }

        /**
         * (experimental) List of package names to include during the upgrade.
         * <p>
         * Default: - Everything is included.
         * <p>
         * @return {@code this}
         * @param include List of package names to include during the upgrade. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(final java.util.List<java.lang.String> include) {
            this.options().include(include);
            return this;
        }

        /**
         * (experimental) Title of the pull request to use (should be all lower-case).
         * <p>
         * Default: "upgrade dependencies"
         * <p>
         * @return {@code this}
         * @param pullRequestTitle Title of the pull request to use (should be all lower-case). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestTitle(final java.lang.String pullRequestTitle) {
            this.options().pullRequestTitle(pullRequestTitle);
            return this;
        }

        /**
         * (experimental) Add Signed-off-by line by the committer at the end of the commit log message.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param signoff Add Signed-off-by line by the committer at the end of the commit log message. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder signoff(final java.lang.Boolean signoff) {
            this.options().signoff(signoff);
            return this;
        }

        /**
         * (experimental) The name of the task that will be created.
         * <p>
         * This will also be the workflow name.
         * <p>
         * Default: "upgrade".
         * <p>
         * @return {@code this}
         * @param taskName The name of the task that will be created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder taskName(final java.lang.String taskName) {
            this.options().taskName(taskName);
            return this;
        }

        /**
         * (experimental) Include a github workflow for creating PR's that upgrades the required dependencies, either by manual dispatch, or by a schedule.
         * <p>
         * If this is <code>false</code>, only a local projen task is created, which can be executed manually to
         * upgrade the dependencies.
         * <p>
         * Default: - true for root projects, false for sub-projects.
         * <p>
         * @return {@code this}
         * @param workflow Include a github workflow for creating PR's that upgrades the required dependencies, either by manual dispatch, or by a schedule. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflow(final java.lang.Boolean workflow) {
            this.options().workflow(workflow);
            return this;
        }

        /**
         * (experimental) Options for the github workflow.
         * <p>
         * Only applies if <code>workflow</code> is true.
         * <p>
         * Default: - default options.
         * <p>
         * @return {@code this}
         * @param workflowOptions Options for the github workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflowOptions(final io.github.cdklabs.projen.javascript.UpgradeDependenciesWorkflowOptions workflowOptions) {
            this.options().workflowOptions(workflowOptions);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.javascript.UpgradeDependencies}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.UpgradeDependencies build() {
            return new io.github.cdklabs.projen.javascript.UpgradeDependencies(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/UpgradeDependencies.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Upgrade node project dependencies.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.549Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.UpgradeDependencies")
public class UpgradeDependencies extends io.github.cdklabs.projen.Component {

    protected UpgradeDependencies(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected UpgradeDependencies(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public UpgradeDependencies(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public UpgradeDependencies(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Add steps to execute a successful build.
     * <p>
     * @param steps workflow steps. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addPostBuildSteps(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.workflows.JobStep... steps) {
        software.amazon.jsii.Kernel.call(this, "addPostBuildSteps", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(steps).toArray(Object[]::new));
    }

    /**
     * (experimental) A task run after the upgrade task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getPostUpgradeTask() {
        return software.amazon.jsii.Kernel.get(this, "postUpgradeTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The upgrade task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getUpgradeTask() {
        return software.amazon.jsii.Kernel.get(this, "upgradeTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The workflows that execute the upgrades.
     * <p>
     * One workflow per branch.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.github.GithubWorkflow> getWorkflows() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubWorkflow.class))));
    }

    /**
     * (experimental) Container definitions for the upgrade workflow.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.workflows.ContainerOptions getContainerOptions() {
        return software.amazon.jsii.Kernel.get(this, "containerOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.ContainerOptions.class));
    }

    /**
     * (experimental) Container definitions for the upgrade workflow.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void setContainerOptions(final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.workflows.ContainerOptions value) {
        software.amazon.jsii.Kernel.set(this, "containerOptions", value);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.UpgradeDependencies}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.UpgradeDependencies> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * (experimental) List of package names to exclude during the upgrade.
         * <p>
         * Default: - Nothing is excluded.
         * <p>
         * @return {@code this}
         * @param exclude List of package names to exclude during the upgrade. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(final java.util.List<java.lang.String> exclude) {
            this.options().exclude(exclude);
            return this;
        }

        /**
         * (experimental) List of package names to include during the upgrade.
         * <p>
         * Default: - Everything is included.
         * <p>
         * @return {@code this}
         * @param include List of package names to include during the upgrade. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(final java.util.List<java.lang.String> include) {
            this.options().include(include);
            return this;
        }

        /**
         * (experimental) Title of the pull request to use (should be all lower-case).
         * <p>
         * Default: "upgrade dependencies"
         * <p>
         * @return {@code this}
         * @param pullRequestTitle Title of the pull request to use (should be all lower-case). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestTitle(final java.lang.String pullRequestTitle) {
            this.options().pullRequestTitle(pullRequestTitle);
            return this;
        }

        /**
         * (experimental) Check peer dependencies of installed packages and filter updates to compatible versions.
         * <p>
         * By default, the upgrade workflow will adhere to version constraints from peer dependencies.
         * Sometimes this is not desirable and can be disabled.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @see <a href="https://github.com/raineorshine/npm-check-updates#peer">https://github.com/raineorshine/npm-check-updates#peer</a>
         * @param satisfyPeerDependencies Check peer dependencies of installed packages and filter updates to compatible versions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder satisfyPeerDependencies(final java.lang.Boolean satisfyPeerDependencies) {
            this.options().satisfyPeerDependencies(satisfyPeerDependencies);
            return this;
        }

        /**
         * (experimental) The semantic commit type.
         * <p>
         * Default: 'chore'
         * <p>
         * @return {@code this}
         * @param semanticCommit The semantic commit type. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticCommit(final java.lang.String semanticCommit) {
            this.options().semanticCommit(semanticCommit);
            return this;
        }

        /**
         * (experimental) Add Signed-off-by line by the committer at the end of the commit log message.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param signoff Add Signed-off-by line by the committer at the end of the commit log message. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder signoff(final java.lang.Boolean signoff) {
            this.options().signoff(signoff);
            return this;
        }

        /**
         * (experimental) Determines the target version to upgrade dependencies to.
         * <p>
         * Default: "minor"
         * <p>
         * @return {@code this}
         * @see <a href="https://github.com/raineorshine/npm-check-updates#target">https://github.com/raineorshine/npm-check-updates#target</a>
         * @param target Determines the target version to upgrade dependencies to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder target(final java.lang.String target) {
            this.options().target(target);
            return this;
        }

        /**
         * (experimental) The name of the task that will be created.
         * <p>
         * This will also be the workflow name.
         * <p>
         * Default: "upgrade".
         * <p>
         * @return {@code this}
         * @param taskName The name of the task that will be created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder taskName(final java.lang.String taskName) {
            this.options().taskName(taskName);
            return this;
        }

        /**
         * (experimental) Specify which dependency types the upgrade should operate on.
         * <p>
         * Default: - All dependency types.
         * <p>
         * @return {@code this}
         * @param types Specify which dependency types the upgrade should operate on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder types(final java.util.List<? extends io.github.cdklabs.projen.DependencyType> types) {
            this.options().types(types);
            return this;
        }

        /**
         * (experimental) Include a github workflow for creating PR's that upgrades the required dependencies, either by manual dispatch, or by a schedule.
         * <p>
         * If this is <code>false</code>, only a local projen task is created, which can be executed manually to
         * upgrade the dependencies.
         * <p>
         * Default: - true for root projects, false for subprojects.
         * <p>
         * @return {@code this}
         * @param workflow Include a github workflow for creating PR's that upgrades the required dependencies, either by manual dispatch, or by a schedule. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflow(final java.lang.Boolean workflow) {
            this.options().workflow(workflow);
            return this;
        }

        /**
         * (experimental) Options for the github workflow.
         * <p>
         * Only applies if <code>workflow</code> is true.
         * <p>
         * Default: - default options.
         * <p>
         * @return {@code this}
         * @param workflowOptions Options for the github workflow. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflowOptions(final io.github.cdklabs.projen.javascript.UpgradeDependenciesWorkflowOptions workflowOptions) {
            this.options().workflowOptions(workflowOptions);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.javascript.UpgradeDependencies}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.UpgradeDependencies build() {
            return new io.github.cdklabs.projen.javascript.UpgradeDependencies(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.javascript.UpgradeDependenciesOptions.Builder();
            }
            return this.options;
        }
    }
}
